Module blaxel.core.sandbox.client.models.file_request
=====================================================

Classes
-------

`FileRequest(content: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>, is_directory: blaxel.core.sandbox.client.types.Unset | bool = <blaxel.core.sandbox.client.types.Unset object>, permissions: blaxel.core.sandbox.client.types.Unset | str = <blaxel.core.sandbox.client.types.Unset object>)`
:   Attributes:
        content (Union[Unset, str]):  Example: file contents here.
        is_directory (Union[Unset, bool]):
        permissions (Union[Unset, str]):  Example: 0644.
    
    Method generated by attrs for class FileRequest.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `content: blaxel.core.sandbox.client.types.Unset | str`
    :

    `is_directory: blaxel.core.sandbox.client.types.Unset | bool`
    :

    `permissions: blaxel.core.sandbox.client.types.Unset | str`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :